==> CoffeeMud_5_9_6.zip: com/planet_ink/coffee_mud/Abilities/Specializations/Specialization_Shield.java <==
package com.planet_ink.coffee_mud.Abilities.Specializations;
import com.planet_ink.coffee_mud.core.interfaces.*;
import com.planet_ink.coffee_mud.core.*;
import com.planet_ink.coffee_mud.core.collections.*;
import com.planet_ink.coffee_mud.Abilities.interfaces.*;
import com.planet_ink.coffee_mud.Areas.interfaces.*;
import com.planet_ink.coffee_mud.Behaviors.interfaces.*;
import com.planet_ink.coffee_mud.CharClasses.interfaces.*;
import com.planet_ink.coffee_mud.Commands.interfaces.*;
import com.planet_ink.coffee_mud.Common.interfaces.*;
import com.planet_ink.coffee_mud.Exits.interfaces.*;
import com.planet_ink.coffee_mud.Items.interfaces.*;
import com.planet_ink.coffee_mud.Libraries.interfaces.*;
import com.planet_ink.coffee_mud.Locales.interfaces.*;
import com.planet_ink.coffee_mud.MOBS.interfaces.*;
import com.planet_ink.coffee_mud.Races.interfaces.*;

import java.util.*;

/*
   Copyright 2014-2017 Bo Zimmerman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

	   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
public class Specialization_Shield extends Specialization_Weapon
{
	@Override
	public String ID()
	{
		return "Specialization_Shield";
	}

	private final static String	localizedName	= CMLib.lang().L("Shield Specialization");

	@Override
	public String name()
	{
		return localizedName;
	}

	public Specialization_Shield()
	{
		super();
		weaponClass=Weapon.CLASS_BLUNT;
	}

	@Override
	protected int getDamageBonus(MOB mob, int dmgType)
	{
		return getXLEVELLevel(mob);
	}

	@Override
	protected boolean isWeaponMatch(Weapon W)
	{
		return W instanceof Shield;
	}

	@Override
	protected boolean canDamage(MOB mob, Weapon W)
	{
		return W instanceof Shield;
	}

	@Override
	protected boolean isWearableItem(Item I)
	{
		return I instanceof Shield;
	}
}

==> CoffeeMud_5_9_8.zip: com/planet_ink/coffee_mud/Abilities/Specializations/Specialization_Shield.java <==
package com.planet_ink.coffee_mud.Abilities.Specializations;
import com.planet_ink.coffee_mud.core.interfaces.*;
import com.planet_ink.coffee_mud.core.*;
import com.planet_ink.coffee_mud.core.collections.*;
import com.planet_ink.coffee_mud.Abilities.interfaces.*;
import com.planet_ink.coffee_mud.Areas.interfaces.*;
import com.planet_ink.coffee_mud.Behaviors.interfaces.*;
import com.planet_ink.coffee_mud.CharClasses.interfaces.*;
import com.planet_ink.coffee_mud.Commands.interfaces.*;
import com.planet_ink.coffee_mud.Common.interfaces.*;
import com.planet_ink.coffee_mud.Exits.interfaces.*;
import com.planet_ink.coffee_mud.Items.interfaces.*;
import com.planet_ink.coffee_mud.Libraries.interfaces.*;
import com.planet_ink.coffee_mud.Locales.interfaces.*;
import com.planet_ink.coffee_mud.MOBS.interfaces.*;
import com.planet_ink.coffee_mud.Races.interfaces.*;

import java.util.*;

/*
   Copyright 2014-2019 Bo Zimmerman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

	   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
public class Specialization_Shield extends Specialization_Weapon
{
	@Override
	public String ID()
	{
		return "Specialization_Shield";
	}

	private final static String	localizedName	= CMLib.lang().L("Shield Specialization");

	@Override
	public String name()
	{
		return localizedName;
	}

	public Specialization_Shield()
	{
		super();
		weaponClass=Weapon.CLASS_BLUNT;
	}

	@Override
	protected int getDamageBonus(final MOB mob, final int dmgType)
	{
		return getXLEVELLevel(mob);
	}

	@Override
	protected boolean isWeaponMatch(final Weapon W)
	{
		return W instanceof Shield;
	}

	@Override
	protected boolean canDamage(final MOB mob, final Weapon W)
	{
		return W instanceof Shield;
	}

	@Override
	protected boolean isWearableItem(final Item I)
	{
		return I instanceof Shield;
	}
}
